@@ -1,4 +1,4 @@
-coordmatch=function(coordref, coordcompare, rad=2, inunitref = "deg", inunitcompare="deg", radunit='asec', sep = ":", kstart=10, ignoreexact=FALSE){
+coordmatch=function(coordref, coordcompare, rad=2, inunitref = "deg", inunitcompare="deg", radunit='asec', sep = ":", kstart=10, ignoreexact=FALSE, ignoreinternal=FALSE, matchextra=FALSE, smallapprox=FALSE){
   if (inunitref %in% c("deg", "rad", "sex") == FALSE) {
     stop("inunitref must be one of deg, rad or sex")
   }
@@ -10,6 +10,12 @@ coordmatch=function(coordref, coordcompare, rad=2, inunitref = "deg", inunitcomp
   }
   origrad=rad
   coordref=rbind(coordref)
+  if(missing(coordcompare)){
+    coordcompare=coordref
+    if(missing(ignoreinternal)){
+      ignoreinternal=TRUE
+    }
+  }
   coordcompare=rbind(coordcompare)
   N=length(coordref[,1])
   kmax=length(coordcompare[,1])
@@ -34,42 +40,64 @@ coordmatch=function(coordref, coordcompare, rad=2, inunitref = "deg", inunitcomp
     coordcompare[,2] = coordcompare[,2] * 180/pi
   }
   if (radunit == "asec"){
-    rad=rad*(pi/180)/3600
+    radmult=(pi/180)/3600
   }
   if (radunit == "amin"){
-    rad=rad*(pi/180)/60
+    radmult=(pi/180)/60
   }
   if (radunit == "deg"){
-    rad=rad*(pi/180)
+    radmult=(pi/180)
   }
+  rad=rad*radmult
   userad=max(rad,na.rm = TRUE)
   
-  coordrefxyz=sph2car(coordref,deg=TRUE)
-  coordcomparexyz=sph2car(coordcompare,deg=TRUE)
+  coordrefxyz=sph2car(coordref[,1:2,drop=FALSE],deg=TRUE)
+  coordcomparexyz=sph2car(coordcompare[,1:2,drop=FALSE],deg=TRUE)
   
-  ksuggest=kstart
+  if(matchextra & dim(coordref)[2]>2 & dim(coordcompare)[2]>2){
+    if(dim(coordref)[2] == dim(coordcompare)[2]){
+      coordrefxyz=cbind(coordrefxyz,coordref[,3:dim(coordref)[2],drop=FALSE]*radmult)
+      coordcomparexyz=cbind(coordcomparexyz,coordcompare[,3:dim(coordcompare)[2],drop=FALSE]*radmult)
+    }
+  }
+  
+  ksuggest=min(kstart, dim(coordcomparexyz)[1])
   while(is.na(ksuggest)==FALSE){
     tempmatch=nn2(coordcomparexyz,coordrefxyz,searchtype='radius',radius=userad,k=ksuggest)
     ignore=tempmatch[[1]]==0
     tempmatch[[2]][ignore]=NA
-    tempmatch[[2]]=2*asin(tempmatch[[2]]/2)
-    if(ignoreexact){remove=which(!(tempmatch[[2]]<=rad & tempmatch[[2]]>0))}else{remove=which(!tempmatch[[2]]<=rad)}
-    tempmatch[[1]][remove]=0
-    tempmatch[[2]][remove]=NA
+    if(smallapprox==FALSE){
+      tempmatch[[2]]=2*asin(tempmatch[[2]]/2)
+    }
+    if(ignoreinternal){
+      remove=which(tempmatch[[1]]-1:length(coordcomparexyz[,1])==0)
+      tempmatch[[1]][remove]=0
+      tempmatch[[2]][remove]=NA
+    }
+    if(ignoreexact){
+      remove=which(!(tempmatch[[2]]<=rad & tempmatch[[2]]>0))
+      tempmatch[[1]][remove]=0
+      tempmatch[[2]][remove]=NA
+    }else{
+      remove=which(!tempmatch[[2]]<=rad)
+      tempmatch[[1]][remove]=0
+      tempmatch[[2]][remove]=NA
+    }
     if (all(is.na(tempmatch[[2]][,ksuggest]))){
       kendmin=NA
     }else{
       kendmin=min(tempmatch[[2]][,ksuggest],na.rm = TRUE)
     }
     if(is.na(kendmin)==FALSE & ksuggest<kmax){
-      ksuggest=ceiling(ksuggest*max(rad/tempmatch[[2]][,ksuggest],na.rm=TRUE))
+      comp=tempmatch[[2]][,ksuggest]
+      ksuggest=ceiling(ksuggest*max(rad[comp>0]/comp[comp>0],na.rm=TRUE))
       ksuggest=min(ksuggest,kmax)
     }else{
       ksuggest=NA
     }
   }
 
-  keepcols=which(apply(is.na(tempmatch[[2]]),2,sum)<N)
+  keepcols=which(colSums(is.na(tempmatch[[2]]))<N)
   tempmatch[[1]]=matrix(tempmatch[[1]][,keepcols],nrow=N,byrow=FALSE)
   tempmatch[[2]]=matrix(tempmatch[[2]][,keepcols],nrow=N,byrow=FALSE)
   
@@ -112,7 +140,7 @@ coordmatch=function(coordref, coordcompare, rad=2, inunitref = "deg", inunitcomp
   return(output)
 }
 
-coordmatchsing=function(RAref,Decref, coordcompare, rad=2, inunitref = "deg", inunitcompare="deg", radunit='asec', sep = ":", ignoreexact=FALSE){
+coordmatchsing=function(RAref,Decref, coordcompare, rad=2, inunitref = "deg", inunitcompare="deg", radunit='asec', sep = ":", ignoreexact=FALSE, smallapprox=FALSE){
   if (inunitref %in% c("deg", "rad", "sex") == FALSE) {
     stop("inunitref must be one of deg, rad or sex")
   }
@@ -147,8 +175,13 @@ coordmatchsing=function(RAref,Decref, coordcompare, rad=2, inunitref = "deg", in
   coordcomparexyz=sph2car(coordcompare,deg=TRUE)
   
   dotprod=coordcomparexyz[,1]*coordrefxyz[1]+coordcomparexyz[,2]*coordrefxyz[2]+coordcomparexyz[,3]*coordrefxyz[3]
-  dotprod[dotprod< -1]=-1;dotprod[dotprod>1]=1
-  ang=acos(dotprod)
+  dotprod[dotprod< -1]=-1
+  dotprod[dotprod>1]=1
+  if(smallapprox==FALSE){
+    ang=acos(dotprod)
+  }else{
+    ang=pi/2-dotprod
+  }
   if (radunit == "asec"){
     ang=ang/((pi/180)/3600)
   }
@@ -171,4 +204,38 @@ coordmatchsing=function(RAref,Decref, coordcompare, rad=2, inunitref = "deg", in
     output=list(ID=ID, sep=sep, Nmatch=length(select), bestmatch=bestmatch)
   }
   return(output)
-}
\ No newline at end of file
+}
+
+internalclean=function(RA, Dec, rad=2, tiebreak, decreasing = FALSE, inunit="deg", radunit='asec', sep = ":"){
+  
+  if (length(dim(RA)) == 2){
+    RA=as.matrix(RA)
+    if(dim(RA)[2]>=2){
+      Dec = RA[, 2]
+    }
+    if(dim(RA)[2]>=3){
+      tiebreak = RA[, 3]
+    }
+    RA = RA[, 1]
+  }
+  
+  RA = as.numeric(RA)
+  Dec = as.numeric(Dec)
+  
+  if(missing(tiebreak)){
+    tiebreak=1:length(RA)
+  }
+  
+  bestfunc=function(x){
+    if(all(x==0)){
+      return(0)
+    }else{
+      return(min(x[x>0],na.rm = TRUE))
+    }
+  }
+  
+  matchorder=order(tiebreak, decreasing=decreasing)
+  match=coordmatch(cbind(RA[matchorder],Dec[matchorder]), rad=rad, inunitref = inunit, inunitcompare = inunit, radunit = radunit, sep = sep)
+  nearcen=apply(cbind(match$bestmatch[,1],match$ID[match$bestmatch[,1],]),1,bestfunc)
+  return=matchorder[c(which(match$Nmatch==0),nearcen)]
+}
