@@ -1,6 +1,6 @@
 skyarea=function(long=c(129,141),lat=c(-2,3),inunit='deg',outunit='deg2',sep=":"){
   if(inunit %in% c('deg','amin','asec','rad','sex')==FALSE){stop('inunit must be one of deg, amin, asec, rad or sex')}
-  if(outunit %in% c('deg2','amin2','asec2','rad2','sr')==FALSE){stop('inunit must be one of deg2, amin2, asec2 or rad2')}
+  if(outunit %in% c('deg2','amin2','asec2','rad2','sr')==FALSE){stop('outunit must be one of deg2, amin2, asec2, rad2 or sr')}
   if(length(long)==1){long=c(0,long)}
   if(length(lat)==1){lat=c(0,lat)}
   fullsky=129600/pi
@@ -16,4 +16,4 @@ skyarea=function(long=c(129,141),lat=c(-2,3),inunit='deg',outunit='deg2',sep=":"
   if(outunit=='asec2'){area=area*12960000}
   if(outunit=='rad2' | outunit=='sr'){area=area/(180/pi)^2}
   return(c(area=area,areafrac=areafrac))
-}
\ No newline at end of file
+}
